[O] renumber/resort footnotes?

2016-11-15 Thread Sharon Kimble

How can I renumber or resort my footnotes please? Something has happened
to them whilst I was working in a narrowed section of my document when I
created a footnote in it. Since then they are not working as they
should.

Thanks
Sharon.
-- 
A taste of linux = http://www.sharons.org.uk
TGmeds = http://www.tgmeds.org.uk
Debian 8.4, fluxbox 1.3.7, emacs 25.1.1


signature.asc
Description: PGP signature


Re: [O] Multiple bibliography files with ox-bibtex and html export

2016-11-15 Thread Thibault Marin

Hi,

I am trying to get back to the multiple bibliography issue discussed
some time ago.

I have two patches proposing two slightly different approaches (from
earlier suggestions):

- 0001-contrib-lisp-ox-bibtex.el-org-bibtex-process-bib-fil.patch creates a
  new bibliography file, a concatenation of all the input files, before calling
  bibtex2html.

- 0001-ox-bibtex.el-Support-multiple-bib-files-in-HTML-expo.patch use
  `start-process' to start the bibtex2html process, then feeds it the input
  bibliography files via stdin.  Once all files are sent it uses a while loop to
  wait for the process to complete (I don't know if there is a better way to do
  that without busy waiting).
  #+BEGIN_SRC emacs-lisp
;; FIXME: How to wait for process to finish?
(while (not process-complete)
  (accept-process-output bibtex2html-proc)
  (sit-for 1)))
  #+END_SRC

Could you please let me know which direction would be preferred, and if changes
should be made to the patch?

Thanks

thibault

>From f093490a3631d4e9de0b18dc5e129eb8049975bc Mon Sep 17 00:00:00 2001
From: thibault 
Date: Tue, 6 Sep 2016 22:42:39 -0500
Subject: [PATCH] * contrib/lisp/ox-bibtex.el (org-bibtex-process-bib-files):
 Add support for multiple bibliography files with html export.

Combine comma-separated bibliography files into a single one and process
it using bibtex2html.  This matches the behavior already present for
latex export.
---
 contrib/lisp/ox-bibtex.el | 18 --
 1 file changed, 16 insertions(+), 2 deletions(-)

diff --git a/contrib/lisp/ox-bibtex.el b/contrib/lisp/ox-bibtex.el
index 56dec38..b46cb76 100644
--- a/contrib/lisp/ox-bibtex.el
+++ b/contrib/lisp/ox-bibtex.el
@@ -191,13 +191,27 @@ Return new parse tree."
 		(file (org-bibtex-get-file keyword))
 		temp-file
 		out-file)
+	(let ((files (split-string file ",")))
+	  (when (< 1 (length files))
+		(let ((combined-bib-file
+		   (concat
+			(file-name-sans-extension
+			 (file-name-nondirectory
+			  (buffer-file-name))) "-combined.bib")))
+		  (with-temp-file combined-bib-file
+		(dolist (bib files)
+		  (insert-file-contents
+		   (if (equal (file-name-extension bib) "bib")
+			   bib
+			 (concat bib ".bib")
+		  (setq file combined-bib-file
 	;; Test if filename is given with .bib-extension and strip
 	;; it off. Filenames with another extensions will be
 	;; untouched and will finally rise an error in bibtex2html.
 	(setq file (if (equal (file-name-extension file) "bib")
 			   (file-name-sans-extension file) file))
 	;; Outpufiles of bibtex2html will be put into current working directory
 	;; so define a variable for this.
 	(setq out-file (file-name-sans-extension
 			(file-name-nondirectory file)))
 	;; limit is set: collect citations throughout the document
@@ -191,13 +191,27 @@ Return new parse tree."
 	(setq file (if (equal (file-name-extension file) "bib")
 			   (file-name-sans-extension file) file))
-	;; Outpufiles of bibtex2html will be put into current working directory
-	;; so define a variable for this.
+	;; Output files of bibtex2html will be put into current
+	;; working directory so define a variable for this.
 	(setq out-file (file-name-sans-extension
 			(file-name-nondirectory file)))
-- 
2.9.3

>From c3056a453efb8bdd39e1dfd6fe4f75090cd1a584 Mon Sep 17 00:00:00 2001
From: thibault 
Date: Tue, 27 Sep 2016 22:36:57 -0500
Subject: [PATCH] ox-bibtex.el: Support multiple bib files in HTML export

* contrib/lisp/ox-bibtex.el (org-bibtex-process-bib-files): Pass
input bibliography files to asynchronous bibtex2html process.
---
 contrib/lisp/ox-bibtex.el | 69 +--
 1 file changed, 49 insertions(+), 20 deletions(-)

diff --git a/contrib/lisp/ox-bibtex.el b/contrib/lisp/ox-bibtex.el
index 56dec38..ca7839f 100644
--- a/contrib/lisp/ox-bibtex.el
+++ b/contrib/lisp/ox-bibtex.el
@@ -188,18 +188,26 @@ Return new parse tree."
   (lambda (keyword)
 	(when (equal (org-element-property :key keyword) "BIBLIOGRAPHY")
 	  (let ((arguments (org-bibtex-get-arguments keyword))
-		(file (org-bibtex-get-file keyword))
+		(files (split-string (org-bibtex-get-file keyword) ","))
 		temp-file
 		out-file)
 	;; Test if filename is given with .bib-extension and strip
-	;; it off. Filenames with another extensions will be
+	;; it off. Filenames with another extensions will be
 	;; untouched and will finally rise an error in bibtex2html.
-	(setq file (if (equal (file-name-extension file) "bib")
-			   (file-name-sans-extension file) file))
-	;; Outpufiles of bibtex2html will be put into current working directory
-	;; so define a variable for this.
-	(setq out-file (file-name-sans-extension
-			(file-name-nondirectory file)))
+	(setq files
+		  (mapcar
+		   (lambda (file)
+		 (if (equal (file-name-extension file) "bib")
+			 (file-name-sans-extension file)
+		   file))
+		   files))
+	;; Output files of bibtex2html will be put into current
+	;; working directory so define a variable for this.
+	(setq out-file
+		  (if (> (length files) 1)
+		  (concat (buffer-file-name) "-combined")
+		  (file-name-sans-extension
+		   (file-name-nondirectory (car files)
 	

Re: [O] ditaa problems?

2016-11-15 Thread Eric S Fraga
On Tuesday, 15 Nov 2016 at 16:26, Peter Davis wrote:
> I'm trying to include a ditaa diagram in a document, but the diagram is
> not drawing correctly. I've attached the source file and the resulting
> png. As you can see, the box around fieldGroup1 is not being drawn for
> some reason. Other boxes appear to be correct.
>
> Any clues? Am I missing something?

I don't think so.  In any case, I don't think it's an org problem.

Your code doesn't work on my system either, although the resulting png
output is different: fieldGroup1 works but some of the ones inside do
not.  In my experience, ditaa is rather fragile.  Leaving bigger gaps
between all edges (top, bottom, sides) and contents, I have found, often
works better.

-- 
: Eric S Fraga (0xFFFCF67D), Emacs 26.0.50.1, Org release_9.0-3-g4c4e84



Re: [O] ditaa problems?

2016-11-15 Thread Peter Davis
Eric S Fraga  writes:

> On Tuesday, 15 Nov 2016 at 16:26, Peter Davis wrote:
>> I'm trying to include a ditaa diagram in a document, but the diagram is
>> not drawing correctly. I've attached the source file and the resulting
>> png. As you can see, the box around fieldGroup1 is not being drawn for
>> some reason. Other boxes appear to be correct.
>>
>> Any clues? Am I missing something?
>
> I don't think so.  In any case, I don't think it's an org problem.
>
> Your code doesn't work on my system either, although the resulting png
> output is different: fieldGroup1 works but some of the ones inside do
> not.  In my experience, ditaa is rather fragile.  Leaving bigger gaps
> between all edges (top, bottom, sides) and contents, I have found, often
> works better.

Thanks, Eric. I did try leaving bigger gaps, but still no joy.

I've sent the file and the png to the ditaa developer on
SourceForge. I'll report back if I find out anything.

Thanks!
-pd



Re: [O] current, working org-protocol bookmarklet for firefox?

2016-11-15 Thread Marco Wahl
Matt Price  writes:

> Does anyone have a current, working org-protocol bookmarklet that will
> capture webpage+document title either in store link format
>
> [[Document title][http://some.url]]
>
> or in a more complex capture template? I have tried various things
> including the firefox plugin and am not having a lot of success. Thank you!!
>
> Does anyone have a current, working org-protocol bookmarklet that will 
> capture webpage+document title either in store link format 
>
> [[Document title][http://some.url]]
>
> or in a more complex capture template? I have tried various things including 
> the firefox plugin and am not having a lot of success. Thank you!!

Don't know about bookmarklet but have you tried the addon

http://chadok.info/firefox-org-capture/

My capture template is

("w" "capture for the bucket (thought for captures from the web via 
org-protocoll)" entry
 (file "~/org/bucket.org")
 "* %:description
:PROPERTIES:
:CREA_DATE:  %U
:END:

:origin:
%U, %c

%i
:END:" :prepend t :empty-lines 1 :clock-in t :clock-resume t)

Currently I'm quite happy with this setting.



HTH,
-- 
Marco




Re: [O] Blank lines after headline and before :PROPERTIES: etc

2016-11-15 Thread Charles Millar

Hi,

On 11/09/2016 06:28 PM, Nicolas Goaziou wrote:

Hello,

Charles Millar  writes:


Is it stated anywhere in the Org manual that blank lines are not
allowed after headlines or certain other elements.

Quoting (info "(org) Property syntax"),

   Properties are key-value pairs. When they are associated with a single
   entry or with a tree they need to be inserted into a special drawer
   (@pxref{Drawers}) with the name @code{PROPERTIES}, which has to be
   located right below a headline, and its planning line
   (@pxref{Deadlines and scheduling}) when applicable.

Improvements are welcome.

Also, see

   http://orgmode.org/worg/dev/org-syntax.html

Eventually,

   M-x org-lint

should report such issue. Actually, it doesn't, but I fixed it so it
will eventually report it.

Regards,


Thank you.





[O] syncing org mobile with cable

2016-11-15 Thread Matthew Pritchard
Is it possible to sync org mobile by cable?



Re: [O] org.texi edits, patch attached

2016-11-15 Thread Nicolas Goaziou
Hello,

Lambda Coder  writes:

> Yes, see attached patch 2.

Thank you.

I have one last suggestion below.

Also, I cannot apply it to maint branch. Could you try rebasing maint
and format patch from there?

> +directory} is not expanded---due to portability issues.

I suggest instead:

  is not expanded, due to portability issues.


Regards,

-- 
Nicolas Goaziou



Re: [O] org.texi edits, patch attached

2016-11-15 Thread Lambda Coder
On Mon, Nov 14, 2016 at 11:47 PM, Nicolas Goaziou 
wrote:

> Could you send an updated patch?
>
> Nicolas Goaziou
>

Yes, see attached patch 2.

--Lambda Coder.


0002-doc-org.texi-Editorial-revisions-to-the-manual.patch.gz
Description: GNU Zip compressed data


[O] current, working org-protocol bookmarklet for firefox?

2016-11-15 Thread Matt Price
Does anyone have a current, working org-protocol bookmarklet that will
capture webpage+document title either in store link format

[[Document title][http://some.url]]

or in a more complex capture template? I have tried various things
including the firefox plugin and am not having a lot of success. Thank you!!


[O] ditaa problems?

2016-11-15 Thread Peter Davis
I'm trying to include a ditaa diagram in a document, but the diagram is
not drawing correctly. I've attached the source file and the resulting
png. As you can see, the box around fieldGroup1 is not being drawn for
some reason. Other boxes appear to be correct.

Any clues? Am I missing something?

Thank you!
-pd

-- 
  Peter Davis
  www.techcurmudgeon.com


containers-ditaa.org
Description: Binary data


Re: [O] SCHEDULED: now needs to be on 2nd line ? - Was: Re: Compact schedule time ranges no longer supported in agenda in org 9 ?

2016-11-15 Thread Marco Wahl

>  ** TODO meeting
>  something
>  SCHEDULED <2016-11-15 Tue 14:00-15:00>
>
> won't work, but :
>
> ** TODO meeting
>  SCHEDULED <2016-11-15 Tue 14:00-15:00>
>  something
>
> works.
>
> Bug, feature ?

This has been discussed on this list already.  Please see other posts
about this question on this list.  E.g. the thread "DEADLINE: position
in entry" a few days ago.


Best regards,
-- 
Marco





[O] SCHEDULED: now needs to be on 2nd line ? - Was: Re: Compact schedule time ranges no longer supported in agenda in org 9 ?

2016-11-15 Thread Olivier Berger
Hi.

Marco Wahl  writes:
>
>> For long I've been using a compact form for defining scheduled tasks
>> with a time range/interval as :
>>
>>  SCHEDULED: <2016-11-14 lun. 14:00-15:00>
>>
>> instead of :
>>
>>  SCHEDULED: <2016-11-14 lun. 14:00>--<2016-11-14 lun. 15:00>
>>
>> It seems this no longer works in org 9 as the tasks don't appear any
>> more in the agenda views.
>>
> I can not confirm your statement.
>
> E.g. the entry
>
> * Meeting
> SCHEDULED: <2016-11-15 Tue 14:00-15:00>
>
> in an agenda file tmp.org appears in my agenda as
>
>   tmp:14:00-15:00 Scheduled:  Meeting
>
> Maybe you can check again and provide a CME?
>

You're right, that still works.

However, the issue is that the SCHEDULED: indication now needs to be
placed on the second line right after the entry's headline, whereas it
used to be recognized even in later lines before org 9...

So :

 ** TODO meeting
 something
 SCHEDULED <2016-11-15 Tue 14:00-15:00>

won't work, but :

** TODO meeting
 SCHEDULED <2016-11-15 Tue 14:00-15:00>
 something

works.

Bug, feature ?

Thanks in advance.

Best regards,
-- 
Olivier BERGER 
http://www-public.telecom-sudparis.eu/~berger_o/ - OpenPGP-Id: 2048R/5819D7E8
Ingenieur Recherche - Dept INF
Institut Mines-Telecom, Telecom SudParis, Evry (France)




Re: [O] Compact schedule time ranges no longer supported in agenda in org 9 ?

2016-11-15 Thread Marco Wahl
Hi,

> For long I've been using a compact form for defining scheduled tasks
> with a time range/interval as :
>
>  SCHEDULED: <2016-11-14 lun. 14:00-15:00>
>
> instead of :
>
>  SCHEDULED: <2016-11-14 lun. 14:00>--<2016-11-14 lun. 15:00>
>
> It seems this no longer works in org 9 as the tasks don't appear any
> more in the agenda views.
>
> I can't seem to find a reference to this "compact form" in the
> manual or changelog... maybe that was an undocumented feature ?
>
> Anyone else with the issue / workaround ?

I can not confirm your statement.

E.g. the entry

* Meeting
SCHEDULED: <2016-11-15 Tue 14:00-15:00>

in an agenda file tmp.org appears in my agenda as

  tmp:14:00-15:00 Scheduled:  Meeting

Maybe you can check again and provide a CME?


Best regards
   Marco





[O] Compact schedule time ranges no longer supported in agenda in org 9 ?

2016-11-15 Thread Olivier Berger
Hi.

For long I've been using a compact form for defining scheduled tasks
with a time range/interval as :

 SCHEDULED: <2016-11-14 lun. 14:00-15:00>

instead of :

 SCHEDULED: <2016-11-14 lun. 14:00>--<2016-11-14 lun. 15:00>

It seems this no longer works in org 9 as the tasks don't appear any
more in the agenda views.

I can't seem to find a reference to this "compact form" in the
manual or changelog... maybe that was an undocumented feature ?

Anyone else with the issue / workaround ?

Thanks in advance.

Best regards,
-- 
Olivier BERGER 
http://www-public.telecom-sudparis.eu/~berger_o/ - OpenPGP-Id: 2048R/5819D7E8
Ingenieur Recherche - Dept INF
Institut Mines-Telecom, Telecom SudParis, Evry (France)